// html5media enables <video> and <audio> tags in all major browsers
// External File: https://api.html5media.info/1.1.8/html5media.min.js


// Add user agent as an attribute on the <html> tag...
// Inspiration: https://css-tricks.com/ie-10-specific-styles/
var b = document.documentElement;
b.setAttribute('data-useragent', navigator.userAgent);
b.setAttribute('data-platform', navigator.platform);


// HTML5 audio player + playlist controls...
// Inspiration: https://jonhall.info/how_to/create_a_playlist_for_html5_audio
// Mythium Archive: https://archive.org/details/mythium/
jQuery(function ($) {
    var supportsAudio = !!document.createElement('audio').canPlayType;
    if (supportsAudio) {
        var index = 0,
            playing = false,
            mediaPath = 'https://t2pn4200-a.akamaihd.net/cdn/websites/dangerous/music/',
            extension = '',
            tracks = [{
                "track": 1,
                "name": "Killer Diller",
                "length": "2:51",
                "file": "1 Killer Diller"
            }, {
                "track": 2,
                "name": "Mayhem",
                "length": "3:43",
                "file": "2 Mayhem"
            }, {
                "track": 3,
                "name": "More Than Meets The Eye",
                "length": "2:37",
                "file": "3 More Than Meets The Eye"
            }, {
                "track": 4,
                "name": "When The Band Begins to Swing",
                "length": "3:07",
                "file": "4 When The Band Begins to Swing"
            }, {
                "track": 5,
                "name": "A Fool Over You",
                "length": "3:05",
                "file": "5 A Fool Over You"
            }, {
                "track": 6,
                "name": "Shubert Alley",
                "length": "3:23",
                "file": "6 Shubert Alley"
            }, {
                "track": 7,
                "name": "Dead Or Alive",
                "length": "2:37",
                "file": "7 Dead Or Alive"
            }, {
                "track": 8,
                "name": "Hello, Hello",
                "length": "3:07",
                "file": "8 Hello, Hello"
            }, {
                "track": 9,
                "name": "Dangerous",
                "length": "3:05",
                "file": "9 Dangerous"
            }, {
                "track": 10,
                "name": "I'll Pretend",
                "length": "3:23",
                "file": "10 I'll Pretend"
            }, {
                "track": 11,
                "name": "Not All Jake",
                "length": "3:07",
                "file": "11 Not All Jake"
            }, {
                "track": 12,
                "name": "Devil In A Bottle",
                "length": "3:05",
                "file": "12 Devil In A Bottle"
            }, {
                "track": 13,
                "name": "Never Again",
                "length": "3:23",
                "file": "13 Never Again"
            }],
            buildPlaylist = $.each(tracks, function(key, value) {
                var trackNumber = value.track,
                    trackName = value.name,
                    trackLength = value.length;
                if (trackNumber.toString().length === 1) {
                    trackNumber = trackNumber;
                } else {
                    trackNumber = '' + trackNumber;
                }
                $('#plList').append('<li><div class="plItem"><div class="plNum">' + trackNumber + '.</div><div class="plTitle">' + trackName + '</div><div class="plLength">' + trackLength + '</div></div></li>');
            }),
            trackCount = tracks.length,
            //npAction = $('#npAction'),
            npTitle = $('#npTitle'),
            audio = $('#audio1').bind('play', function () {
                playing = true;
                //npAction.text('Now Playing...');
            }).bind('pause', function () {
                playing = false;
                //npAction.text('Paused...');
            }).bind('ended', function () {
                //npAction.text('Paused...');
                if ((index + 1) < trackCount) {
                    index++;
                    loadTrack(index);
                    audio.play();
                } else {
                    audio.pause();
                    index = 0;
                    loadTrack(index);
                }
            }).get(0),
            btnPrev = $('#btnPrev').click(function () {
                if ((index - 1) > -1) {
                    index--;
                    loadTrack(index);
                    if (playing) {
                        audio.play();
                    }
                } else {
                    audio.pause();
                    index = 0;
                    loadTrack(index);
                }
            }),
            btnNext = $('#btnNext').click(function () {
                if ((index + 1) < trackCount) {
                    index++;
                    loadTrack(index);
                    if (playing) {
                        audio.play();
                    }
                } else {
                    audio.pause();
                    index = 0;
                    loadTrack(index);
                }
            }),
            li = $('#plList li').click(function () {
                var id = parseInt($(this).index());
                if (id !== index) {
                    playTrack(id);
                }
            }),
            loadTrack = function (id) {
                $('.plSel').removeClass('plSel');
                $('#plList li:eq(' + id + ')').addClass('plSel');
                npTitle.text(tracks[id].name);
                index = id;
                audio.src = mediaPath + tracks[id].file + extension;
            },
            playTrack = function (id) {
                loadTrack(id);
                audio.play();
            };
        extension = audio.canPlayType('audio/mpeg') ? '.mp3' : audio.canPlayType('audio/ogg') ? '.ogg' : '';
        loadTrack(index);
    }
});