/**
 * Quote Rotation Script
 * @author SpotCo
 */

/* Quote Rotator Namespace */
var qr = {};

/* Default config settings */
qr.settings = {
    quoteData : null, quoteLoop : true, quoteWrapper : null, rotationCount : 0, rotateSpeed : 0, infiniteLoop : false
};

/**
 * Function to retrieve quote data.
 * @param dataSrc: is the path/url to the quote data
 * @param quoteElem: is id of the HTML element that will contain the quotes
 */
qr.getQuoteData = function (dataSrc, quoteElem, speed, infiniteLoop) {"use strict";
    var httpRequest = new XMLHttpRequest ();
    httpRequest.onreadystatechange = function () {
        if (httpRequest.readyState === 4) {
            if (httpRequest.status === 200) {
                var data = JSON.parse (httpRequest.responseText);
                qr.storeQuotes (data, quoteElem, speed, infiniteLoop);
            }
        }
    };

    httpRequest.open ('GET', dataSrc);
    httpRequest.send (null);
};

/**
 *  Function to store quotes data
 * @param data: is the data returned by AJAX request
 * @param quoteElem: is id of the HTML element that will contain the quotes. This
 * was passed through from the getQuoteData function
 * */
qr.storeQuotes = function (data, quoteElem, speed, infiniteLoop) {"use strict";
    qr.settings.quoteData = data;
    qr.settings.quoteWrapper = quoteElem;
    qr.settings.rotateSpeed = speed;
    qr.settings.infiniteLoop = infiniteLoop;
    qr.startLoop ();
};

// Start interval loop
qr.startLoop = function () {"use strict";
    console.log ('start');
    qr.settings.quoteLoop = setInterval (qr.quotator, qr.settings.rotateSpeed);
};

// Stops interval loop
qr.stopLoop = function () {"use strict";
    clearInterval (qr.settings.quoteLoop);
};

// Function that displays quotes
qr.quotator = function () {"use strict";
    var qCount = qr.settings.rotationCount;
    var qData = qr.settings.quoteData;
    var qDataLen = qr.settings.quoteData.length;
    var qElem = qr.settings.quoteWrapper;
    var quoteSturcture = document.getElementById (qElem).innerHTML = '<span class="quotetext">' + qData [qCount].quote + '</span><br><cite>' + qData [qCount].author + '</cite>';

    //
    if (qr.settings.infiniteLoop === true) {
        console.log (qCount, qDataLen);
        if (qCount === qDataLen - 1) { quoteSturcture;
            qr.settings.rotationCount = 0;
            console.log ('restarting');
        } else { quoteSturcture;
            qr.settings.rotationCount++;
        }
    } else {
        if (qCount === qDataLen) {
            clearInterval (qr.settings.quoteLoop);
            console.log ('stop');
        } else { quoteSturcture;
            qr.settings.rotationCount++;
        }
    }
};

/* Start Quotator Program */
//qr.getQuoteData ('_data/quotes.json', 'quotes', 2000, true);
